/*
 * Copyright (c) 2002, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package javasoft.sqe.tests.javax.mail.internet.MimeBodyPart;

import java.util.*;
import java.io.*;
import javax.mail.*;
import javax.mail.internet.*;
import com.sun.javatest.*;
import javasoft.sqe.tests.javax.mail.util.MailTest;

/**
 * This class tests the <strong>getAllHeaderLines()</strong> API.
 * It does by passing various valid input values and then checking
 * the type of the returned object.	<p>
 *
 *              Get all header lines as an Enumeration of Strings. <p>
 * api2test: public void getAllHeaderLines()  <p>
 *
 * how2test: Call API, it will return an enumerated list of all header lines. If
 *           operation is a success then this testcase passes, otherwise it fails.
 */

public class getAllHeaderLines_Test extends MailTest {

    public static void main( String argv[] )
    {
        getAllHeaderLines_Test test = new getAllHeaderLines_Test();
        Status s = test.run(argv, System.err, System.out);
	s.exit();
    }

    public Status run(String argv[], PrintWriter log, PrintWriter out)
    {
	super.run(argv, log, out);
	parseArgs(argv);	// parse command-line options

        out.println("\nTesting class MimeBodyPart: getAllHeaderLines()\n");

        try {
          // Connect to host server
             Store store = connect2host(protocol, host, user, password);

          // Get a Folder object
	     Folder root = getRootFolder(store);
             Folder folder = root.getFolder(mailbox);

             if( folder == null ) {
                 return Status.failed("Invalid folder object!");
             }
             folder.open(Folder.READ_ONLY);

	     if( msgcount == -1 ) {
                 msgcount = folder.getMessageCount();
                 if( msgcount < 1 )
                     return Status.failed("Mail folder is empty!");
             }

             for( int i = 1; i <= msgcount; i++ )
             {
             // Get the message
                MimeMessage msg = (MimeMessage)folder.getMessage(i);

	        if ( msg == null ) {
		    log.println("WARNING: FAILED TO GET MESSAGE NUMBER: "+ i);
		    continue;
	        }
	     // BEGIN UNIT TEST:
		// Get bodypart content
	        out.println("UNIT TEST "+ i +":  getAllHeaderLines()");

		// Get the "type" of content
	        Object content = msg.getContent();

		if( content instanceof Multipart ) {
		    int bodycount = ((MimeMultipart)content).getCount();
		    for( int k = 0; k < bodycount; k++ )
		    {
		     	 BodyPart bp = ((MimeMultipart)content).getBodyPart(k);
			 // get all header lines
			 Enumeration allheaders = ((MimeBodyPart)bp).getAllHeaderLines(); // API TEST

			 while ( allheaders.hasMoreElements() ) {
				 String headers = (String)allheaders.nextElement();
				 out.println(headers);
			 }
			 out.println("UNIT TEST "+ i +": passed");
		    }
		}
	     // END UNIT TEST:
	     }
	     folder.close(false);
	     store.close();
	     checkStatus();

        } catch ( Exception e ) {
	     handlException(e);
        }
	return status;
     }
}
